@@ -117,15 +117,15 @@
 #define DEFENSE_EMPHASIS 20
 
 struct tile_data_cache {
-  char food;    /* food output of the tile */
-  char trade;   /* trade output of the tile */
-  char shield;  /* shield output of the tile */
+  short food;   /* Food output of the tile */
+  short trade;  /* Trade output of the tile */
+  short shield; /* Shield output of the tile */
 
-  int sum;      /* weighted sum of the tile output (used by AI) */
+  int sum;      /* Weighted sum of the tile output */
 
-  int reserved; /* reservation for this tile; used by print_citymap() */
+  int reserved; /* Reservation for this tile; used by print_citymap() */
 
-  int turn;     /* the turn the values were calculated */
+  int turn;     /* The turn the values were calculated */
 };
 
 
@@ -285,6 +285,7 @@ static struct cityresult *cityresult_fill(struct ai_type *ait,
   bool handicap = has_handicap(pplayer, H_MAP);
   struct adv_data *adv = adv_data_get(pplayer, NULL);
   struct cityresult *result;
+  const struct civ_map *nmap = &(wld.map);
 
   fc_assert_ret_val(adv != NULL, NULL);
   fc_assert_ret_val(center != NULL, NULL);
@@ -294,7 +295,7 @@ static struct cityresult *cityresult_fill(struct ai_type *ait,
   /* Create a city result and set default values. */
   result = cityresult_new(center);
 
-  if (!pcity) {
+  if (pcity == NULL) {
     pcity = create_city_virtual(pplayer, result->tile, "Virtuaville");
     saved_owner = tile_owner(result->tile);
     saved_claimer = tile_claimer(result->tile);
@@ -305,7 +306,7 @@ static struct cityresult *cityresult_fill(struct ai_type *ait,
 
   result->city_radius_sq = city_map_radius_sq_get(pcity);
 
-  city_tile_iterate_index(result->city_radius_sq, result->tile, ptile,
+  city_tile_iterate_index(nmap, result->city_radius_sq, result->tile, ptile,
                           cindex) {
     int tindex = tile_index(ptile);
     int reserved = citymap_read(ptile);
@@ -314,7 +315,7 @@ static struct cityresult *cityresult_fill(struct ai_type *ait,
 
     if (reserved < 0
         || (handicap && !map_is_known(ptile, pplayer))
-        || NULL != tile_worked(ptile)) {
+        || tile_worked(ptile) != NULL) {
       /* Tile is reserved or we can't see it */
       ptdc = tile_data_cache_new();
       ptdc->shield = 0;
@@ -325,6 +326,7 @@ static struct cityresult *cityresult_fill(struct ai_type *ait,
       /* ptdc->turn was set by tile_data_cache_new(). */
     } else {
       const struct tile_data_cache *ptdc_hit = tdc_plr_get(ait, pplayer, tindex);
+
       if (!ptdc_hit || city_center) {
         /* We cannot read city center from cache */
         ptdc = tile_data_cache_new();
@@ -373,24 +375,33 @@ static struct cityresult *cityresult_fill(struct ai_type *ait,
       result->best_other.tile = ptile;
       result->best_other.cindex = cindex;
     } else if (ptdc->sum > result->best_other.tdc->sum) {
-      /* First add other other to remaining */
-      result->remaining += result->best_other.tdc->sum
-                           / GROWTH_POTENTIAL_DEEMPHASIS;
+      /* First add other other to remaining, unless it's unavailable (value < 0) tile. */
+      if (result->best_other.tdc->sum > 0) {
+        result->remaining += result->best_other.tdc->sum
+                             / GROWTH_POTENTIAL_DEEMPHASIS;
+      }
       /* Then make new best other */
       result->best_other.tdc = ptdc;
       result->best_other.tile = ptile;
       result->best_other.cindex = cindex;
     } else {
       /* Save total remaining calculation, divided by crowdedness
-       * of the area and the emphasis placed on space for growth. */
-      result->remaining += ptdc->sum / GROWTH_POTENTIAL_DEEMPHASIS;
+       * of the area and the emphasis placed on space for growth.
+       * Do not add unavailable (value < 0) tiles. */
+      if (ptdc->sum > 0) {
+        result->remaining += ptdc->sum / GROWTH_POTENTIAL_DEEMPHASIS;
+      }
     }
 
     tile_data_cache_hash_replace(result->tdc_hash, cindex, ptdc);
   } city_tile_iterate_index_end;
 
   /* We need a city center. */
-  fc_assert_ret_val(result->city_center.tdc != NULL, NULL);
+  if (result->city_center.tdc == NULL) {
+    fc_assert(result->city_center.tdc != NULL);
+
+    return NULL;
+  }
 
   if (virtual_city) {
     /* Baseline is a size one city (city center + best extra tile). */
