@@ -43,7 +43,7 @@
 #include "options.h"
 #include "text.h"
 
-/* clien/gui-gtk-3.22 */
+/* clien/gui-gtk-3.0 */
 #include "plrdlg.h"
 #include "dialogs.h"
 #include "gui_main.h"
@@ -128,7 +128,6 @@ static void goto_cmd_callback(GtkWidget *dlg, gint arg)
   dshell = NULL;
 }
 
-
 /**********************************************************************//**
   Create goto -dialog for gotoing or airlifting unit
 **************************************************************************/
@@ -139,15 +138,15 @@ static void create_goto_dialog(void)
   GtkTreeViewColumn *col;
 
   dshell = gtk_dialog_new_with_buttons(_("Goto/Airlift Unit"),
-                                       NULL,
-                                       0,
-                                       _("_Cancel"),
-                                       GTK_RESPONSE_CANCEL,
-                                       _("Air_lift"),
-                                       CMD_AIRLIFT,
-                                       _("_Goto"),
-                                       CMD_GOTO,
-                                       NULL);
+    NULL,
+    0,
+    GTK_STOCK_CANCEL,
+    GTK_RESPONSE_CANCEL,
+    _("Air_lift"),
+    CMD_AIRLIFT,
+    _("_Goto"),
+    CMD_GOTO,
+    NULL);
   setup_dialog(dshell, toplevel);
   gtk_window_set_position(GTK_WINDOW(dshell), GTK_WIN_POS_MOUSE);
   gtk_dialog_set_default_response(GTK_DIALOG(dshell), CMD_GOTO);
