@@ -44,7 +44,7 @@
 #include "packhand.h"
 #include "text.h"
 
-/* client/gui-gtk-4.0 */
+/* client/gui-gtk-3.22 */
 #include "citydlg.h"
 #include "dialogs.h"
 #include "unitselextradlg.h"
@@ -334,7 +334,7 @@ static void simple_action_callback(GtkWidget *w, gpointer data)
   }
 
   /* Clean up. */
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   /* No follow up questions. */
   act_sel_dialog_data = NULL;
   FC_FREE(args);
@@ -409,7 +409,7 @@ static void request_action_details_callback(GtkWidget *w, gpointer data)
   is_more_user_input_needed = TRUE;
 
   /* Clean up. */
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   /* No client side follow up questions. */
   act_sel_dialog_data = NULL;
   FC_FREE(args);
@@ -423,9 +423,10 @@ static void found_city_callback(GtkWidget *w, gpointer data)
   struct action_data *args = act_sel_dialog_data;
 
   dsend_packet_city_name_suggestion_req(&client.conn,
+                                        args->actor_unit_id,
                                         args->actor_unit_id);
 
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   free(args);
 }
 
@@ -448,7 +449,7 @@ static void upgrade_callback(GtkWidget *w, gpointer data)
     unit_list_destroy(as_list);
   }
 
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   free(args);
 }
 
@@ -464,7 +465,7 @@ static void bribe_response(GtkWidget *w, gint response, gpointer data)
                       args->target_unit_id, 0, "");
   }
 
-  gtk_window_destroy(GTK_WINDOW(w));
+  gtk_widget_destroy(w);
   free(args);
 
   /* The user have answered the follow up question. Move on. */
@@ -503,7 +504,7 @@ void popup_bribe_dialog(struct unit *actor, struct unit *punit, int cost,
     setup_dialog(shell, toplevel);
   }
   gtk_window_present(GTK_WINDOW(shell));
-
+  
   g_signal_connect(shell, "response", G_CALLBACK(bribe_response),
                    act_data(paction->id, actor->id,
                             0, punit->id, 0,
@@ -535,7 +536,7 @@ static void spy_advances_response(GtkWidget *w, gint response,
     }
   }
 
-  gtk_window_destroy(GTK_WINDOW(spy_tech_shell));
+  gtk_widget_destroy(spy_tech_shell);
   spy_tech_shell = NULL;
   free(data);
 
@@ -556,12 +557,12 @@ static void spy_advances_callback(GtkTreeSelection *select,
 
   if (gtk_tree_selection_get_selected(select, &model, &it)) {
     gtk_tree_model_get(model, &it, 1, &(args->target_tech_id), -1);
-
+    
     gtk_dialog_set_response_sensitive(GTK_DIALOG(spy_tech_shell),
       GTK_RESPONSE_ACCEPT, TRUE);
   } else {
     args->target_tech_id = 0;
-
+	  
     gtk_dialog_set_response_sensitive(GTK_DIALOG(spy_tech_shell),
       GTK_RESPONSE_ACCEPT, FALSE);
   }
@@ -573,8 +574,8 @@ static void spy_advances_callback(GtkTreeSelection *select,
 static void create_advances_list(struct player *pplayer,
 				 struct player *pvictim,
 				 struct action_data *args)
-{
-  GtkWidget *sw, *frame, *label, *vgrid, *view;
+{  
+  GtkWidget *sw, *label, *vbox, *view;
   GtkListStore *store;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
@@ -587,19 +588,20 @@ static void create_advances_list(struct player *pplayer,
                                                _("_Steal"), GTK_RESPONSE_ACCEPT,
                                                NULL);
   setup_dialog(spy_tech_shell, toplevel);
+  gtk_window_set_position(GTK_WINDOW(spy_tech_shell), GTK_WIN_POS_MOUSE);
 
   gtk_dialog_set_default_response(GTK_DIALOG(spy_tech_shell),
 				  GTK_RESPONSE_ACCEPT);
 
-  frame = gtk_frame_new(_("Select Advance to Steal"));
-  gtk_box_append(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(spy_tech_shell))), frame);
+  label = gtk_frame_new(_("Select Advance to Steal"));
+  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(spy_tech_shell))), label);
 
-  vgrid = gtk_grid_new();
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vgrid),
+  vbox = gtk_grid_new();
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
                                  GTK_ORIENTATION_VERTICAL);
-  gtk_grid_set_row_spacing(GTK_GRID(vgrid), 6);
-  gtk_frame_set_child(GTK_FRAME(frame), vgrid);
-
+  gtk_grid_set_row_spacing(GTK_GRID(vbox), 6);
+  gtk_container_add(GTK_CONTAINER(label), vbox);
+      
   store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
@@ -620,17 +622,18 @@ static void create_advances_list(struct player *pplayer,
     "xalign", 0.0,
     "yalign", 0.5,
     NULL);
-  gtk_grid_attach(GTK_GRID(vgrid), label, 0, 0, 1, 1);
-
-  sw = gtk_scrolled_window_new();
-  gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(sw), TRUE);
-  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
+  gtk_container_add(GTK_CONTAINER(vbox), label);
+  
+  sw = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
+				      GTK_SHADOW_ETCHED_IN);
+  gtk_container_add(GTK_CONTAINER(sw), view);
 
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
     GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
   gtk_widget_set_size_request(sw, -1, 200);
-
-  gtk_grid_attach(GTK_GRID(vgrid), sw, 0, 1, 1, 1);
+  
+  gtk_container_add(GTK_CONTAINER(vbox), sw);
 
   /* Now populate the list */
   if (pvictim) { /* you don't want to know what lag can do -- Syela */
@@ -676,14 +679,14 @@ static void create_advances_list(struct player *pplayer,
 
   gtk_dialog_set_response_sensitive(GTK_DIALOG(spy_tech_shell),
     GTK_RESPONSE_ACCEPT, FALSE);
-
-  gtk_widget_show(gtk_dialog_get_content_area(GTK_DIALOG(spy_tech_shell)));
+  
+  gtk_widget_show_all(gtk_dialog_get_content_area(GTK_DIALOG(spy_tech_shell)));
 
   g_signal_connect(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), "changed",
                    G_CALLBACK(spy_advances_callback), args);
   g_signal_connect(spy_tech_shell, "response",
                    G_CALLBACK(spy_advances_response), args);
-
+  
   args->target_tech_id = 0;
 
   gtk_tree_view_focus(GTK_TREE_VIEW(view));
@@ -721,7 +724,7 @@ static void spy_improvements_response(GtkWidget *w, gint response, gpointer data
     }
   }
 
-  gtk_window_destroy(GTK_WINDOW(spy_sabotage_shell));
+  gtk_widget_destroy(spy_sabotage_shell);
   spy_sabotage_shell = NULL;
   free(args);
 
@@ -741,12 +744,12 @@ static void spy_improvements_callback(GtkTreeSelection *select, gpointer data)
 
   if (gtk_tree_selection_get_selected(select, &model, &it)) {
     gtk_tree_model_get(model, &it, 1, &(args->target_building_id), -1);
-
+    
     gtk_dialog_set_response_sensitive(GTK_DIALOG(spy_sabotage_shell),
       GTK_RESPONSE_ACCEPT, TRUE);
   } else {
     args->target_building_id = -2;
-
+	  
     gtk_dialog_set_response_sensitive(GTK_DIALOG(spy_sabotage_shell),
       GTK_RESPONSE_ACCEPT, FALSE);
   }
@@ -758,34 +761,35 @@ static void spy_improvements_callback(GtkTreeSelection *select, gpointer data)
 static void create_improvements_list(struct player *pplayer,
 				     struct city *pcity,
 				     struct action_data *args)
-{
-  GtkWidget *sw, *frame, *label, *vgrid, *view;
+{  
+  GtkWidget *sw, *label, *vbox, *view;
   GtkListStore *store;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
   GtkTreeIter it;
 
   struct unit *actor_unit = game_unit_by_number(args->actor_unit_id);
-
+  
   spy_sabotage_shell = gtk_dialog_new_with_buttons(_("Sabotage Improvements"),
                                                    NULL, 0,
                                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
                                                    _("_Sabotage"), GTK_RESPONSE_ACCEPT,
                                                    NULL);
   setup_dialog(spy_sabotage_shell, toplevel);
+  gtk_window_set_position(GTK_WINDOW(spy_sabotage_shell), GTK_WIN_POS_MOUSE);
 
   gtk_dialog_set_default_response(GTK_DIALOG(spy_sabotage_shell),
 				  GTK_RESPONSE_ACCEPT);
 
-  frame = gtk_frame_new(_("Select Improvement to Sabotage"));
-  gtk_box_append(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(spy_sabotage_shell))), frame);
+  label = gtk_frame_new(_("Select Improvement to Sabotage"));
+  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(spy_sabotage_shell))), label);
 
-  vgrid = gtk_grid_new();
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vgrid),
+  vbox = gtk_grid_new();
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
                                  GTK_ORIENTATION_VERTICAL);
-  gtk_grid_set_row_spacing(GTK_GRID(vgrid), 6);
-  gtk_frame_set_child(GTK_FRAME(frame), vgrid);
-
+  gtk_grid_set_row_spacing(GTK_GRID(vbox), 6);
+  gtk_container_add(GTK_CONTAINER(label), vbox);
+      
   store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
@@ -806,17 +810,18 @@ static void create_improvements_list(struct player *pplayer,
     "xalign", 0.0,
     "yalign", 0.5,
     NULL);
-  gtk_grid_attach(GTK_GRID(vgrid), label, 0, 0, 1, 1);
-
-  sw = gtk_scrolled_window_new();
-  gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(sw), TRUE);
-  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
+  gtk_container_add(GTK_CONTAINER(vbox), label);
+  
+  sw = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
+				      GTK_SHADOW_ETCHED_IN);
+  gtk_container_add(GTK_CONTAINER(sw), view);
 
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
     GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
   gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(sw), 200);
-
-  gtk_grid_attach(GTK_GRID(vgrid), sw, 0, 1, 1, 1);
+  
+  gtk_container_add(GTK_CONTAINER(vbox), sw);
 
   /* Now populate the list */
   if (action_prob_possible(actor_unit->client.act_prob_cache[
@@ -833,7 +838,7 @@ static void create_improvements_list(struct player *pplayer,
                          0, city_improvement_name_translation(pcity, pimprove),
                          1, improvement_number(pimprove),
                          -1);
-    }
+    }  
   } city_built_iterate_end;
 
   if (action_prob_possible(actor_unit->client.act_prob_cache[
@@ -851,9 +856,9 @@ static void create_improvements_list(struct player *pplayer,
   }
 
   gtk_dialog_set_response_sensitive(GTK_DIALOG(spy_sabotage_shell),
-                                    GTK_RESPONSE_ACCEPT, FALSE);
-
-  gtk_widget_show(gtk_dialog_get_content_area(GTK_DIALOG(spy_sabotage_shell)));
+    GTK_RESPONSE_ACCEPT, FALSE);
+  
+  gtk_widget_show_all(gtk_dialog_get_content_area(GTK_DIALOG(spy_sabotage_shell)));
 
   g_signal_connect(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), "changed",
                    G_CALLBACK(spy_improvements_callback), args);
@@ -861,7 +866,7 @@ static void create_improvements_list(struct player *pplayer,
                    G_CALLBACK(spy_improvements_response), args);
 
   args->target_building_id = -2;
-
+	  
   gtk_tree_view_focus(GTK_TREE_VIEW(view));
 }
 
@@ -897,7 +902,7 @@ pvictim to NULL and account for !pvictim in create_advances_list. -- Syela */
    * needs to know what action to take. */
   is_more_user_input_needed = TRUE;
 
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
 }
 
 /**********************************************************************//**
@@ -949,7 +954,7 @@ static void incite_response(GtkWidget *w, gint response, gpointer data)
                       args->target_city_id, 0, "");
   }
 
-  gtk_window_destroy(GTK_WINDOW(w));
+  gtk_widget_destroy(w);
   free(args);
 
   /* The user have answered the follow up question. Move on. */
@@ -996,7 +1001,7 @@ void popup_incite_dialog(struct unit *actor, struct city *pcity, int cost,
     setup_dialog(shell, toplevel);
   }
   gtk_window_present(GTK_WINDOW(shell));
-
+  
   g_signal_connect(shell, "response", G_CALLBACK(incite_response),
                    act_data(paction->id, actor->id,
                             pcity->id, 0, 0,
@@ -1022,17 +1027,18 @@ static void tgt_unit_change_callback(GtkWidget *dlg, gint arg)
       if (tgt_unit == NULL) {
         /* Make the action dialog pop up again. */
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id,
+                                      actor->id, actor->id,
                                       /* Let the server choose the target
                                        * unit. */
                                       IDENTITY_NUMBER_ZERO,
+                                      IDENTITY_NUMBER_ZERO,
                                       tgt_tile->index,
                                       action_selection_target_extra(),
                                       REQEST_PLAYER_INITIATED);
       } else {
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id,
-                                      tgt_id,
+                                      actor->id, actor->id,
+                                      tgt_id, tgt_id,
                                       tgt_tile->index,
                                       action_selection_target_extra(),
                                       REQEST_PLAYER_INITIATED);
@@ -1043,7 +1049,7 @@ static void tgt_unit_change_callback(GtkWidget *dlg, gint arg)
     action_selection_no_longer_in_progress(au_id);
   }
 
-  gtk_window_destroy(GTK_WINDOW(dlg));
+  gtk_widget_destroy(dlg);
 }
 
 /**********************************************************************//**
@@ -1070,7 +1076,7 @@ static void act_sel_new_unit_tgt_callback(GtkWidget *w, gpointer data)
 
   did_not_decide = TRUE;
   action_selection_restart = TRUE;
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   free(args);
 }
 
@@ -1089,12 +1095,13 @@ static void tgt_extra_change_callback(GtkWidget *dlg, gint arg)
                                                      "target"));
       struct extra_type *tgt_extra = extra_by_number(tgt_id);
       struct tile *tgt_tile = g_object_get_data(G_OBJECT(dlg), "tile");
+      int tgt_unit = action_selection_target_unit();
 
       if (tgt_extra == NULL) {
         /* Make the action dialog pop up again. */
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id,
-                                      action_selection_target_unit(),
+                                      actor->id, actor->id,
+                                      tgt_unit, tgt_unit,
                                       tgt_tile->index,
                                       /* Let the server choose the target
                                        * extra. */
@@ -1102,8 +1109,8 @@ static void tgt_extra_change_callback(GtkWidget *dlg, gint arg)
                                       REQEST_PLAYER_INITIATED);
       } else {
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id,
-                                      action_selection_target_unit(),
+                                      actor->id, actor->id,
+                                      tgt_unit, tgt_unit,
                                       tgt_tile->index,
                                       tgt_id,
                                       REQEST_PLAYER_INITIATED);
@@ -1114,7 +1121,7 @@ static void tgt_extra_change_callback(GtkWidget *dlg, gint arg)
     action_selection_no_longer_in_progress(au_id);
   }
 
-  gtk_window_destroy(GTK_WINDOW(dlg));
+  gtk_widget_destroy(dlg);
 }
 
 /**********************************************************************//**
@@ -1168,7 +1175,7 @@ static void act_sel_new_extra_tgt_callback(GtkWidget *w, gpointer data)
 
   did_not_decide = TRUE;
   action_selection_restart = TRUE;
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   free(args);
 }
 
@@ -1215,16 +1222,18 @@ static void act_sel_destroy_callback(GtkWidget *w, gpointer data)
 **************************************************************************/
 static void act_sel_cancel_callback(GtkWidget *w, gpointer data)
 {
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   free(act_sel_dialog_data);
 }
 
 /**********************************************************************//**
   Action selection dialog has been closed
 **************************************************************************/
-static void act_sel_close_callback(GtkWidget *w, gpointer data)
+static void act_sel_close_callback(GtkWidget *w,
+                                   gint response_id,
+                                   gpointer data)
 {
-  choice_dialog_destroy(act_sel_dialog);
+  gtk_widget_destroy(act_sel_dialog);
   free(act_sel_dialog_data);
 }
 
@@ -1555,7 +1564,7 @@ void popup_action_selection(struct unit *actor_unit,
   choice_dialog_set_hide(shl, TRUE);
   g_signal_connect(shl, "destroy",
                    G_CALLBACK(act_sel_destroy_callback), NULL);
-  g_signal_connect(shl, "close-request",
+  g_signal_connect(shl, "delete_event",
                    G_CALLBACK(act_sel_close_callback),
                    GINT_TO_POINTER(ACTION_NONE));
 
@@ -1727,6 +1736,6 @@ void action_selection_close(void)
 {
   if (act_sel_dialog != NULL) {
     did_not_decide = TRUE;
-    choice_dialog_destroy(act_sel_dialog);
+    gtk_widget_destroy(act_sel_dialog);
   }
 }
