@@ -331,7 +331,7 @@ bool can_unit_change_homecity_to(const struct unit *punit,
                                  const struct city *pcity);
 bool can_unit_change_homecity(const struct unit *punit);
 const char *get_activity_text(enum unit_activity activity);
-bool can_unit_continue_current_activity(struct civ_map *nmap,
+bool can_unit_continue_current_activity(const struct civ_map *nmap,
                                         struct unit *punit);
 bool can_unit_do_activity(const struct civ_map *nmap,
                           const struct unit *punit,
@@ -508,7 +508,8 @@ bool unit_can_convert(const struct civ_map *nmap, const struct unit *punit);
 int unit_pays_mp_for_action(const struct action *paction,
                             const struct unit *punit);
 
-int hp_gain_coord(struct unit *punit);
+int hp_gain_coord(const struct unit *punit);
+int unit_gain_hitpoints(const struct unit *punit);
 bool is_losing_hp(const struct unit *punit);
 bool unit_type_is_losing_hp(const struct player *pplayer,
                             const struct unit_type *punittype);
@@ -560,8 +561,10 @@ struct iterator *cargo_iter_init(struct cargo_iter *iter,
                   cargo_iter_sizeof, cargo_iter_init, _ptrans)
 #define unit_cargo_iterate_end generic_iterate_end
 
-bool unit_order_list_is_sane(int length, const struct unit_order *orders);
-struct unit_order *create_unit_orders(int length,
+bool unit_order_list_is_sane(const struct civ_map *nmap,
+                             int length, const struct unit_order *orders);
+struct unit_order *create_unit_orders(const struct civ_map *nmap,
+                                      int length,
                                       const struct unit_order *orders);
 
 #ifdef __cplusplus
