@@ -1001,6 +1001,7 @@ action_auto_perf_unit_do(const enum action_auto_perf_cause cause,
   const struct city *tgt_city;
   const struct tile *tgt_tile;
   const struct unit *tgt_unit;
+  const struct civ_map *nmap = &(wld.map);
 
   const struct action_auto_perf *autoperf
       = action_auto_perf_unit_sel(cause, actor, other_player,
@@ -1030,21 +1031,21 @@ action_auto_perf_unit_do(const enum action_auto_perf_cause cause,
       switch (action_id_get_target_kind(act)) {
       case ATK_UNITS:
         if (tgt_tile
-            && is_action_enabled_unit_on_units(act, actor, tgt_tile)) {
+            && is_action_enabled_unit_on_units(nmap, act, actor, tgt_tile)) {
           perform_action_to(act, actor, tgt_tile->index, EXTRA_NONE);
         }
         break;
       case ATK_TILE:
         if (tgt_tile
-            && is_action_enabled_unit_on_tile(act, actor, tgt_tile,
-                                              target_extra)) {
+            && is_action_enabled_unit_on_tile(nmap, act, actor,
+                                              tgt_tile, target_extra)) {
           perform_action_to(act, actor, tgt_tile->index,
                             target_extra ? extra_number(target_extra) : -1);
         }
         break;
       case ATK_EXTRAS:
         if (tgt_tile
-            && is_action_enabled_unit_on_extras(act, actor,
+            && is_action_enabled_unit_on_extras(nmap, act, actor,
                                                 tgt_tile, target_extra)) {
           perform_action_to(act, actor, tgt_tile->index,
                             target_extra ? extra_number(target_extra) : -1);
@@ -1052,13 +1053,13 @@ action_auto_perf_unit_do(const enum action_auto_perf_cause cause,
         break;
       case ATK_CITY:
         if (tgt_city
-            && is_action_enabled_unit_on_city(act, actor, tgt_city)) {
+            && is_action_enabled_unit_on_city(nmap, act, actor, tgt_city)) {
           perform_action_to(act, actor, tgt_city->id, EXTRA_NONE)
         }
         break;
       case ATK_UNIT:
         if (tgt_unit
-            && is_action_enabled_unit_on_unit(act, actor, tgt_unit)) {
+            && is_action_enabled_unit_on_unit(nmap, act, actor, tgt_unit)) {
           perform_action_to(act, actor, tgt_unit->id, EXTRA_NONE);
         }
         break;
@@ -1102,6 +1103,7 @@ action_auto_perf_unit_prob(const enum action_auto_perf_cause cause,
   const struct city *tgt_city;
   const struct tile *tgt_tile;
   const struct unit *tgt_unit;
+  const struct civ_map *nmap = &(wld.map);
 
   const struct action_auto_perf *autoperf
       = action_auto_perf_unit_sel(cause, actor, other_player,
@@ -1126,19 +1128,20 @@ action_auto_perf_unit_prob(const enum action_auto_perf_cause cause,
       switch (action_id_get_target_kind(act)) {
       case ATK_UNITS:
         if (tgt_tile
-            && is_action_enabled_unit_on_units(act, actor, tgt_tile)) {
+            && is_action_enabled_unit_on_units(nmap, act, actor, tgt_tile)) {
           current = action_prob_vs_units(actor, act, tgt_tile);
         }
         break;
       case ATK_TILE:
         if (tgt_tile
-            && is_action_enabled_unit_on_tile(act, actor, tgt_tile, target_extra)) {
+            && is_action_enabled_unit_on_tile(nmap, act, actor,
+                                              tgt_tile, target_extra)) {
           current = action_prob_vs_tile(actor, act, tgt_tile, target_extra);
         }
         break;
       case ATK_EXTRAS:
         if (tgt_tile
-            && is_action_enabled_unit_on_extras(act, actor,
+            && is_action_enabled_unit_on_extras(nmap, act, actor,
                                                 tgt_tile, target_extra)) {
           current = action_prob_vs_extras(actor, act,
                                           tgt_tile, target_extra);
@@ -1146,13 +1149,13 @@ action_auto_perf_unit_prob(const enum action_auto_perf_cause cause,
         break;
       case ATK_CITY:
         if (tgt_city
-            && is_action_enabled_unit_on_city(act, actor, tgt_city)) {
+            && is_action_enabled_unit_on_city(nmap, act, actor, tgt_city)) {
           current = action_prob_vs_city(actor, act, tgt_city);
         }
         break;
       case ATK_UNIT:
         if (tgt_unit
-            && is_action_enabled_unit_on_unit(act, actor, tgt_unit)) {
+            && is_action_enabled_unit_on_unit(nmap, act, actor, tgt_unit)) {
           current = action_prob_vs_unit(actor, act, tgt_unit);
         }
         break;
