@@ -416,10 +416,11 @@ void give_citymap_from_player_to_player(struct city *pcity,
 					struct player *pfrom, struct player *pdest)
 {
   struct tile *pcenter = city_tile(pcity);
+  const struct civ_map *nmap = &(wld.map);
 
   buffer_shared_vision(pdest);
 
-  city_tile_iterate(city_map_radius_sq_get(pcity), pcenter, ptile) {
+  city_tile_iterate(nmap, city_map_radius_sq_get(pcity), pcenter, ptile) {
     give_tile_info_from_player_to_player(pfrom, pdest, ptile);
   } city_tile_iterate_end;
 
@@ -519,22 +520,32 @@ void send_tile_info(struct conn_list *dest, struct tile *ptile,
     }
 
     if (!pplayer || map_is_known_and_seen(ptile, pplayer, V_MAIN)) {
+      struct extra_type *resource;
+
       info.known = TILE_KNOWN_SEEN;
       info.continent = tile_continent(ptile);
       owner = tile_owner(ptile);
       eowner = extra_owner(ptile);
       info.owner = (owner ? player_number(owner) : MAP_TILE_OWNER_NULL);
       info.extras_owner = (eowner ? player_number(eowner) : MAP_TILE_OWNER_NULL);
-      info.worked = (NULL != tile_worked(ptile))
-                     ? tile_worked(ptile)->id
-                     : IDENTITY_NUMBER_ZERO;
+      info.worked32 = (NULL != tile_worked(ptile))
+                      ? tile_worked(ptile)->id
+                      : IDENTITY_NUMBER_ZERO;
+      info.worked16 = info.worked32;
 
       info.terrain = (NULL != tile_terrain(ptile))
                       ? terrain_number(tile_terrain(ptile))
                       : terrain_count();
-      info.resource = (NULL != tile_resource(ptile))
-                       ? extra_number(tile_resource(ptile))
-                       : MAX_EXTRA_TYPES;
+
+      resource = tile_resource(ptile);
+      if (resource != NULL
+          && (pplayer == NULL
+              || player_knows_extra_exist(pplayer, resource, ptile))) {
+        info.resource = extra_number(resource);
+      } else {
+        info.resource = MAX_EXTRA_TYPES;
+      }
+
       info.placing = (NULL != ptile->placing)
                       ? extra_number(ptile->placing)
                       : -1;
@@ -568,9 +579,10 @@ void send_tile_info(struct conn_list *dest, struct tile *ptile,
       eowner = plrtile->extras_owner;
       info.owner = (owner ? player_number(owner) : MAP_TILE_OWNER_NULL);
       info.extras_owner = (eowner ? player_number(eowner) : MAP_TILE_OWNER_NULL);
-      info.worked = (NULL != psite)
-                    ? psite->identity
-                    : IDENTITY_NUMBER_ZERO;
+      info.worked32 = (NULL != psite)
+                      ? psite->identity
+                      : IDENTITY_NUMBER_ZERO;
+      info.worked16 = info.worked32;
 
       info.terrain = (NULL != plrtile->terrain)
                       ? terrain_number(plrtile->terrain)
@@ -596,7 +608,8 @@ void send_tile_info(struct conn_list *dest, struct tile *ptile,
       info.continent = 0;
       info.owner = MAP_TILE_OWNER_NULL;
       info.extras_owner = MAP_TILE_OWNER_NULL;
-      info.worked = IDENTITY_NUMBER_ZERO;
+      info.worked32 = IDENTITY_NUMBER_ZERO;
+      info.worked16 = IDENTITY_NUMBER_ZERO;
 
       info.terrain = terrain_count();
       info.resource = MAX_EXTRA_TYPES;
@@ -760,17 +773,17 @@ void map_show_tile(struct player *src_player, struct tile *ptile)
       if (!map_is_known_and_seen(ptile, pplayer, V_MAIN)) {
 	map_set_known(ptile, pplayer);
 
-	/* as the tile may be fogged send_tile_info won't always do this for us */
+	/* As the tile may be fogged send_tile_info won't always do this for us */
 	update_player_tile_knowledge(pplayer, ptile);
 	update_player_tile_last_seen(pplayer, ptile);
 
         send_tile_info(pplayer->connections, ptile, FALSE);
 
-	/* remove old cities that exist no more */
+	/* Remove old cities that exist no more */
 	reality_check_city(pplayer, ptile);
 
 	if ((pcity = tile_city(ptile))) {
-	  /* as the tile may be fogged send_city_info won't do this for us */
+	  /* As the tile may be fogged send_city_info won't do this for us */
 	  update_dumb_city(pplayer, pcity);
 	  send_city_info(pplayer, pcity);
 	}
@@ -1384,7 +1397,12 @@ bool update_player_tile_knowledge(struct player *pplayer, struct tile *ptile)
 	BV_CLR(plrtile->extras, extra_number(pextra));
       }
     } extra_type_iterate_end;
-    plrtile->resource = ptile->resource;
+    if (ptile->resource != NULL
+        && player_knows_extra_exist(pplayer, ptile->resource, ptile)) {
+      plrtile->resource = ptile->resource;
+    } else {
+      plrtile->resource = NULL;
+    }
     plrtile->owner = tile_owner(ptile);
     plrtile->extras_owner = extra_owner(ptile);
 
