@@ -346,7 +346,7 @@ bool api_edit_perform_action_unit_vs_city(lua_State *L, Unit *punit,
   fc_assert_ret_val(action_get_actor_kind(paction) == AAK_UNIT, FALSE);
   fc_assert_ret_val(action_get_target_kind(paction) == ATK_CITY, FALSE);
   fc_assert_ret_val(!action_has_result(paction, ACTRES_FOUND_CITY), FALSE);
-  if (is_action_enabled_unit_on_city(paction->id, punit, tgt)) {
+  if (is_action_enabled_unit_on_city(&(wld.map), paction->id, punit, tgt)) {
     return unit_perform_action(unit_owner(punit), punit->id,
                                tgt->id, IDENTITY_NUMBER_ZERO, "",
                                paction->id, ACT_REQ_RULES);
@@ -372,7 +372,7 @@ bool api_edit_perform_action_unit_vs_city_impr(lua_State *L, Unit *punit,
   fc_assert_ret_val(action_get_actor_kind(paction) == AAK_UNIT, FALSE);
   fc_assert_ret_val(action_get_target_kind(paction) == ATK_CITY, FALSE);
   fc_assert_ret_val(!action_has_result(paction, ACTRES_FOUND_CITY), FALSE);
-  if (is_action_enabled_unit_on_city(paction->id, punit, tgt)) {
+  if (is_action_enabled_unit_on_city(&(wld.map), paction->id, punit, tgt)) {
     return unit_perform_action(unit_owner(punit), punit->id,
                                tgt->id, sub_tgt->item_number, "",
                                paction->id, ACT_REQ_RULES);
@@ -398,7 +398,7 @@ bool api_edit_perform_action_unit_vs_city_tech(lua_State *L, Unit *punit,
   fc_assert_ret_val(action_get_actor_kind(paction) == AAK_UNIT, FALSE);
   fc_assert_ret_val(action_get_target_kind(paction) == ATK_CITY, FALSE);
   fc_assert_ret_val(!action_has_result(paction, ACTRES_FOUND_CITY), FALSE);
-  if (is_action_enabled_unit_on_city(paction->id, punit, tgt)) {
+  if (is_action_enabled_unit_on_city(&(wld.map), paction->id, punit, tgt)) {
     return unit_perform_action(unit_owner(punit), punit->id,
                                tgt->id, sub_tgt->item_number, "",
                                paction->id, ACT_REQ_RULES);
@@ -414,6 +414,8 @@ bool api_edit_perform_action_unit_vs_city_tech(lua_State *L, Unit *punit,
 bool api_edit_perform_action_unit_vs_unit(lua_State *L, Unit *punit,
                                           Action *paction, Unit *tgt)
 {
+  const struct civ_map *nmap = &(wld.map);
+
   LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_ARG_NIL(L, punit, 2, Unit, FALSE);
   LUASCRIPT_CHECK_ARG_NIL(L, paction, 3, Action, FALSE);
@@ -422,7 +424,7 @@ bool api_edit_perform_action_unit_vs_unit(lua_State *L, Unit *punit,
   fc_assert_ret_val(action_get_actor_kind(paction) == AAK_UNIT, FALSE);
   fc_assert_ret_val(action_get_target_kind(paction) == ATK_UNIT, FALSE);
   fc_assert_ret_val(!action_has_result(paction, ACTRES_FOUND_CITY), FALSE);
-  if (is_action_enabled_unit_on_unit(paction->id, punit, tgt)) {
+  if (is_action_enabled_unit_on_unit(nmap, paction->id, punit, tgt)) {
     return unit_perform_action(unit_owner(punit), punit->id,
                                tgt->id, IDENTITY_NUMBER_ZERO, "",
                                paction->id, ACT_REQ_RULES);
@@ -439,6 +441,7 @@ bool api_edit_perform_action_unit_vs_tile(lua_State *L, Unit *punit,
                                           Action *paction, Tile *tgt)
 {
   bool enabled = FALSE;
+  const struct civ_map *nmap = &(wld.map);
 
   LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_ARG_NIL(L, punit, 2, Unit, FALSE);
@@ -448,14 +451,14 @@ bool api_edit_perform_action_unit_vs_tile(lua_State *L, Unit *punit,
   fc_assert_ret_val(action_get_actor_kind(paction) == AAK_UNIT, FALSE);
   switch (action_get_target_kind(paction)) {
   case ATK_UNITS:
-    enabled = is_action_enabled_unit_on_units(paction->id, punit, tgt);
+    enabled = is_action_enabled_unit_on_units(nmap, paction->id, punit, tgt);
     break;
   case ATK_TILE:
-    enabled = is_action_enabled_unit_on_tile(paction->id, punit,
+    enabled = is_action_enabled_unit_on_tile(nmap, paction->id, punit,
                                              tgt, NULL);
     break;
   case ATK_EXTRAS:
-    enabled = is_action_enabled_unit_on_extras(paction->id, punit,
+    enabled = is_action_enabled_unit_on_extras(nmap, paction->id, punit,
                                                tgt, NULL);
     break;
   case ATK_CITY:
@@ -496,6 +499,7 @@ bool api_edit_perform_action_unit_vs_tile_extra(lua_State *L, Unit *punit,
 {
   struct extra_type *sub_target;
   bool enabled = FALSE;
+  const struct civ_map *nmap = &(wld.map);
 
   LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_ARG_NIL(L, punit, 2, Unit, FALSE);
@@ -509,14 +513,14 @@ bool api_edit_perform_action_unit_vs_tile_extra(lua_State *L, Unit *punit,
   fc_assert_ret_val(action_get_actor_kind(paction) == AAK_UNIT, FALSE);
   switch (action_get_target_kind(paction)) {
   case ATK_UNITS:
-    enabled = is_action_enabled_unit_on_units(paction->id, punit, tgt);
+    enabled = is_action_enabled_unit_on_units(nmap, paction->id, punit, tgt);
     break;
   case ATK_TILE:
-    enabled = is_action_enabled_unit_on_tile(paction->id, punit,
+    enabled = is_action_enabled_unit_on_tile(nmap, paction->id, punit,
                                              tgt, sub_target);
     break;
   case ATK_EXTRAS:
-    enabled = is_action_enabled_unit_on_extras(paction->id, punit,
+    enabled = is_action_enabled_unit_on_extras(nmap, paction->id, punit,
                                                tgt, sub_target);
     break;
   case ATK_CITY:
