@@ -21,6 +21,7 @@
 // Qt
 #include <QDialog>
 
+class QGridLayout;
 class QLineEdit;
 class QSpinBox;
 
@@ -42,6 +43,9 @@ class edit_terrain : public QDialog
     QLineEdit *gfx_tag;
     QLineEdit *gfx_tag_alt;
 
+    QGridLayout *natives_layout;
+    QGridLayout *flag_layout;
+
   protected:
     void closeEvent(QCloseEvent *cevent);
 
